searchData={"items":[{"type":"module","title":"HtmlQuery","doc":"Some simple HTML query functions. Delegates the hard work to [Floki](https://hex.pm/packages/floki).","ref":"HtmlQuery.html"},{"type":"module","title":"Data types - HtmlQuery","doc":"All functions accept HTML in the form of a string, a Floki HTML tree, or a Floki HTML node.\nOthers expect only a Floki HTML node or a Floki HTML tree. See `t:HtmlQuery.html/0`.\n\nSome functions take a CSS selector, which can be a string, a keyword list, or a list.\nSee `t:HtmlQuery.Css.selector/0`.","ref":"HtmlQuery.html#module-data-types"},{"type":"module","title":"Main query functions - HtmlQuery","doc":"The main query functions take an HTML string or some parsed HTML, and a selector.\n\n| `all/2`         | return all elements matching the selector          |\n| `find/2`        | return the first element that matches the selector |\n| `find!/2`       | return the only element that matches the selector  |","ref":"HtmlQuery.html#module-main-query-functions"},{"type":"module","title":"Extraction functions - HtmlQuery","doc":"| `attr/2`        | returns the attribute value as a string              |\n| `form_fields/1` | returns the names and values of form fields as a map |\n| `meta_tags/1`   | returns the names and values of metadata fields      |\n| `table/2`       | returns the cells of a table as a list of lists      |\n| `text/1`        | returns the text contents as a single string         |","ref":"HtmlQuery.html#module-extraction-functions"},{"type":"module","title":"Parsing functions - HtmlQuery","doc":"| `parse/1`     | parses an HTML fragment into a [Floki HTML tree] |\n| `parse_doc/1` | parses an HTML doc into a [Floki HTML tree]      |","ref":"HtmlQuery.html#module-parsing-functions"},{"type":"module","title":"Utility functions - HtmlQuery","doc":"| `inspect_html/2` | prints prettified HTML with a label   |\n| `normalize/1`    | parses and re-stringifies HTML        |\n| `pretty/1`       | prettifies HTML                       |\n| `reject/2`       | removes nodes that match the selector |","ref":"HtmlQuery.html#module-utility-functions"},{"type":"module","title":"Alias - HtmlQuery","doc":"If you use HtmlQuery a lot, you may want to alias it to the recommended shortcut \"Hq\":\n```elixir\nalias HtmlQuery, as: Hq\n```","ref":"HtmlQuery.html#module-alias"},{"type":"module","title":"Examples - HtmlQuery","doc":"Get the value of a selected option:\n\n```elixir\niex> html = ~s|   apples   bananas   |\niex> HtmlQuery.find(html, \"select option[selected]\") |> HtmlQuery.attr(\"value\")\n\"a\"\n```\n\nGet the text of a selected option, raising if there are more than one:\n\n```elixir\niex> html = ~s|   apples   bananas   |\niex> HtmlQuery.find!(html, \"select option[selected]\") |> HtmlQuery.text()\n\"apples\"\n```\n\nGet the text of all the options:\n\n```elixir\niex> html = ~s|   apples   bananas   |\niex> HtmlQuery.all(html, \"select option\") |> Enum.map(&HtmlQuery.text/1)\n[\"apples\", \"bananas\"]\n```\n\nUse a keyword list as the selector (see `HtmlQuery.Css` for details on selectors):\n\n```elixir\niex> html = ~s|   logout   |\niex> HtmlQuery.find!(html, test_role: \"logout-link\") |> HtmlQuery.attr(\"href\")\n\"/logout\"\n```","ref":"HtmlQuery.html#module-examples"},{"type":"function","title":"HtmlQuery.all/2","doc":"Finds all elements in `html` that match `selector`, returning a Floki HTML tree.\n\n```elixir\niex> html = ~s|   apples   bananas   |\niex> HtmlQuery.all(html, \"option\")\n[\n  {\"option\", [{\"value\", \"a\"}, {\"selected\", \"selected\"}], [\"apples\"]},\n  {\"option\", [{\"value\", \"b\"}], [\"bananas\"]}\n]\n```","ref":"HtmlQuery.html#all/2"},{"type":"function","title":"HtmlQuery.attr/2","doc":"Returns the value of `attr` from the outermost element of `html`.\nIf `attr` is an atom, any underscores are converted to dashes.\n\n```elixir\niex> html = ~s|   logout   |\niex> HtmlQuery.find!(html, test_role: \"logout-link\") |> HtmlQuery.attr(\"href\")\n\"/logout\"\n```","ref":"HtmlQuery.html#attr/2"},{"type":"function","title":"HtmlQuery.find/2","doc":"Finds the first element in `html` that matches `selector`, returning a Floki HTML node.\n\n```elixir\niex> html = ~s|   apples   bananas   |\niex> HtmlQuery.find(html, \"select option[selected]\")\n{\"option\", [{\"value\", \"a\"}, {\"selected\", \"selected\"}], [\"apples\"]}\n```","ref":"HtmlQuery.html#find/2"},{"type":"function","title":"HtmlQuery.find!/2","doc":"Like `find/2` but raises unless exactly one element is found.","ref":"HtmlQuery.html#find!/2"},{"type":"function","title":"HtmlQuery.form_fields/1","doc":"Returns a map containing the form fields of form `selector` in `html`. Because it returns a map, any information\nabout the order of form fields is lost.\n\n```elixir\niex> html = ~s|     A tree   |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{color: \"green\", desc: \"A tree\"}\n```\n\nField names are converted to snake case atoms:\n\n```elixir\niex> html = ~s|     |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{favorite_color: \"green\"}\n```\n\nIf form field names are in `foo[bar]` format, then `foo` becomes a key to a nested map containing `bar`:\n\n```elixir\niex> html = ~s|       |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{profile: %{name: \"fido\", age: \"10\"}}\n```\n\nIf a text field has no value attribute, it will not be returned at all:\n\n```elixir\niex> html = ~s|     |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{}\n\niex> html = ~s|     |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{empty_value: \"\"}\n\niex> html = ~s|     |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{non_empty_value: \"something\"}\n```\n\nThe checked value of a radio button set is returned, or `nil` is returned if no value is checked:\n\n```elixir\niex> html = ~s|       |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{x: \"2\"}\n\niex> html = ~s|       |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{x: nil}\n```\n\nAll checked values of checkboxes are returned as a list, or `[]` is returned if no values are checked:\n\n```elixir\niex> html = ~s|       |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{x: [\"1\", \"2\"]}\n\niex> html = ~s|       |\niex> html |> HtmlQuery.find(\"form\") |> HtmlQuery.form_fields()\n%{x: []}\n```","ref":"HtmlQuery.html#form_fields/1"},{"type":"function","title":"HtmlQuery.inspect_html/2","doc":"Prints prettified `html` with a label, and then returns the original html.","ref":"HtmlQuery.html#inspect_html/2"},{"type":"function","title":"HtmlQuery.meta_tags/1","doc":"Extracts all the meta tags from `html`, returning a list of maps.\n\n```elixir\niex> html = ~s|       |\niex> HtmlQuery.meta_tags(html)\n[%{\"charset\" => \"utf-8\"}, %{\"content\" => \"IE=edge\", \"http-equiv\" => \"X-UA-Compatible\"}]\n```","ref":"HtmlQuery.html#meta_tags/1"},{"type":"function","title":"HtmlQuery.normalize/1","doc":"Parses and then re-stringifies `html`, increasing the liklihood that two equivalent HTML strings can\nbe considered equal.\n\n```elixir\niex> a = ~s| green |\niex> b = ~s| green |\niex> a == b\nfalse\niex> HtmlQuery.normalize(a) == HtmlQuery.normalize(b)\ntrue\n```","ref":"HtmlQuery.html#normalize/1"},{"type":"function","title":"HtmlQuery.parse/1","doc":"Parses an HTML fragment using `Floki.parse_fragment!/1`, returning a Floki HTML tree.","ref":"HtmlQuery.html#parse/1"},{"type":"function","title":"HtmlQuery.parse_doc/1","doc":"Parses an HTML document using `Floki.parse_document!/1`, returning a Floki HTML tree.","ref":"HtmlQuery.html#parse_doc/1"},{"type":"function","title":"HtmlQuery.pretty/1","doc":"Returns `html` as a prettified string (delgates to `Floki.raw_html/2` with the `pretty: true` option).","ref":"HtmlQuery.html#pretty/1"},{"type":"function","title":"HtmlQuery.reject/2","doc":"Returns `html` after removing all nodes that don't match `selector` (delegates to `Floki.filter_out/2`).\n\n```elixir\niex> html = ~s|   Alice   topaz   |\niex> HtmlQuery.reject(html, id: \"password\") |> HtmlQuery.normalize()\n~s|  Alice  |\n```","ref":"HtmlQuery.html#reject/2"},{"type":"function","title":"HtmlQuery.table/2","doc":"Returns the contents of the table as a list of lists.\n\nOptions:\n* `as` - if `:lists` (the default), returns the table as a list of lists; if `:maps`, returns the table as a list of\n  maps.\n* `columns` - a list of the indices of the columns to return; a list of column headers (as strings) to return,\n  assuming that the first row of the table is the columns names; or `:all` to return all columns (which is the same\n  as not specifying this option all all).\n* `headers` - if `true` (the default), returns the list of headers along with the rows. Ignored if `as` option is\n  `:map`.\n\n```elixir\niex> html = \"    A  B  C     1  2  3    \"\niex> HtmlQuery.table(html)\n[\n  [\"A\", \"B\", \"C\"],\n  [\"1\", \"2\", \"3\"]\n]\niex> HtmlQuery.table(html, as: :maps)\n[\n  %{\"A\" => \"1\", \"B\" => \"2\", \"C\" => \"3\"}\n]\niex> HtmlQuery.table(html, columns: [0, 2])\n[\n  [\"A\", \"C\"],\n  [\"1\", \"3\"]\n]\niex> HtmlQuery.table(html, columns: [2, 0])\n[\n  [\"C\", \"A\"],\n  [\"3\", \"1\"]\n]\niex> HtmlQuery.table(html, columns: [\"C\", \"A\"])\n[\n  [\"C\", \"A\"],\n  [\"3\", \"1\"]\n]\niex> HtmlQuery.table(html, columns: [\"C\", \"A\"], headers: false)\n[\n  [\"3\", \"1\"]\n]\n```","ref":"HtmlQuery.html#table/2"},{"type":"function","title":"HtmlQuery.text/1","doc":"Returns the text value of `html`.\n\n```elixir\niex> html = ~s|   apples   bananas   |\niex> HtmlQuery.find!(html, \"select option[selected]\") |> HtmlQuery.text()\n\"apples\"\n```","ref":"HtmlQuery.html#text/1"},{"type":"type","title":"HtmlQuery.attr/0","doc":"A string or atom representing an attribute name. If an atom, underscores are converted to dashes.","ref":"HtmlQuery.html#t:attr/0"},{"type":"type","title":"HtmlQuery.html/0","doc":"A string, a struct that implements the `String.Chars` protocol,\na [Floki HTML tree], or a [Floki HTML node].\n\n[Floki HTML tree]: https://hexdocs.pm/floki/Floki.html#t:html_tree/0\n[Floki HTML node]: https://hexdocs.pm/floki/Floki.html#t:html_node/0","ref":"HtmlQuery.html#t:html/0"},{"type":"module","title":"HtmlQuery.Css","doc":"Constructs CSS selectors via Elixir data structures. See `selector/1` for details.","ref":"HtmlQuery.Css.html"},{"type":"function","title":"HtmlQuery.Css.selector/1","doc":"Accepts a string, atom, keyword list, or list, and returns a CSS string.","ref":"HtmlQuery.Css.html#selector/1"},{"type":"function","title":"String syntax - HtmlQuery.Css.selector/1","doc":"When given a string, returns the string. This is useful when you don't know if a selector is already a string.\n\n```elixir\niex> HtmlQuery.Css.selector(\".profile[test-role='new-members']\")\n\".profile[test-role='new-members']\"\n```","ref":"HtmlQuery.Css.html#selector/1-string-syntax"},{"type":"function","title":"Atom syntax - HtmlQuery.Css.selector/1","doc":"When given an atom, converts the atom to a string, without converting underscores to dashes.\n\n```elixir\niex> HtmlQuery.Css.selector(:p)\n\"p\"\n```","ref":"HtmlQuery.Css.html#selector/1-atom-syntax"},{"type":"function","title":"Keyword list syntax - HtmlQuery.Css.selector/1","doc":"_The keyword list syntax is intentionally limited; complex selectors are more\neasily written as strings._\n\nThe keyword list syntax makes it a bit eaiser to write simple selectors or selectors that use variables:\ne.g.:\n\n```elixir\nHtmlQuery.Css.selector(test_role: \"new-members\")\nHtmlQuery.Css.selector(id: some_variable)\n```\n\nKeys are expected to be atoms and will be dasherized (`foo_bar` -> `foo-bar`).\nValues are expected to be strings or another keyword list.\n\nA key/value pair will be converted to an attribute selector:\n```elixir\niex> HtmlQuery.Css.selector(test_role: \"new-members\")\n\"[test-role='new-members']\"\n```\n\nA keyword list will be converted to a list of attribute selectors:\n\n```elixir\niex> HtmlQuery.Css.selector(class: \"profile\", test_role: \"new-members\")\n\"[class='profile'][test-role='new-members']\"\n```\n\n(Note that the CSS selector `.profile` expands to `[class~='profile']` which is not equivalent to\n`[class='profile']`. The keyword list syntax will not generate `~=` selectors so you should use a\nstring selector such as `\".profile[test-role='new-members']\"` instead if you want `~=` semantics. See the\n[CSS spec](https://www.w3.org/TR/CSS21/selector.html#attribute-selectors) for details.)\n\nWhen the value is a keyword list, the key is converted to an element selector:\n\n```elixir\niex> HtmlQuery.Css.selector(p: [class: \"profile\", test_role: \"new-members\"])\n\"p[class='profile'][test-role='new-members']\"\n```","ref":"HtmlQuery.Css.html#selector/1-keyword-list-syntax"},{"type":"function","title":"List syntax - HtmlQuery.Css.selector/1","doc":"_The list syntax is intentionally limited; complex selectors are more\neasily written as strings._\n\nWhen the value is a list (vs a keyword list), atoms are converted to element selectors and\nkeyword lists are converted as described above.\n\n```elixir\niex> HtmlQuery.Css.selector([[p: [class: \"profile\", test_role: \"new-members\"]], :div, [class: \"tag\"]])\n\"p[class='profile'][test-role='new-members'] div [class='tag']\"\n```","ref":"HtmlQuery.Css.html#selector/1-list-syntax"},{"type":"type","title":"HtmlQuery.Css.selector/0","doc":"See docs for `selector/1` for more details.","ref":"HtmlQuery.Css.html#t:selector/0"},{"type":"module","title":"HtmlQuery.Form","doc":"Form-handling functions. Most of the time, `HtmlQuery.form_fields/1` should be used instead of calling these\nfunctions directly.","ref":"HtmlQuery.Form.html"},{"type":"function","title":"HtmlQuery.Form.fields/1","doc":"","ref":"HtmlQuery.Form.html#fields/1"},{"type":"exception","title":"HtmlQuery.QueryError","doc":"An exception raised when unable to find an HTML element.","ref":"HtmlQuery.QueryError.html"},{"type":"extras","title":"HtmlQuery","doc":"# HtmlQuery\n\nSome simple HTML query functions.\nDelegates the hard work to [Floki](https://hex.pm/packages/floki).\n\n```elixir\niex> alias HtmlQuery, as: Hq\n\niex> html = \"\"\"\n   \n     Name    \n     Age    \n     Bio  Fido likes long walks and playing fetch.   \n   \n \n\"\"\"\n\niex> html |> Hq.find!(test_role: \"profile\")\n{\"form\", [{\"id\", \"profile\"}, {\"test-role\", \"profile\"}],\n [\n   {\"label\", [], [ \"Name \", {\"input\", [{\"name\", \"name\"}, {\"type\", \"text\"}, {\"value\", \"Fido\"}], []} ]},\n   {\"label\", [], [ \"Age \", {\"input\", [{\"name\", \"age\"}, {\"type\", \"text\"}, {\"value\", \"10\"}], []} ]},\n   {\"label\", [], [ \"Bio \", {\"textarea\", [{\"name\", \"bio\"}], [\"Fido likes long walks and playing fetch.\"]} ]}\n ]\n}\n\niex> html |> Hq.all(\"input[type=text]\") |> Enum.map(&Hq.attr(&1, \"value\"))\n[\"Fido\", \"10\"]\n\niex> html |> Hq.find(test_role: \"profile\") |> Hq.form_fields()\n%{age: \"10\", bio: \"Fido likes long walks and playing fetch.\", name: \"Fido\"}\n```","ref":"readme.html"},{"type":"extras","title":"API Docs - HtmlQuery","doc":"See the documentation for the main `HtmlQuery` module for details and more examples:","ref":"readme.html#api-docs"},{"type":"extras","title":"Installation - HtmlQuery","doc":"```elixir\ndef deps do\n  [\n    {:html_query, \"~> 1.2\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"LICENSE","doc":"Copyright 2022 synchronal.dev\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the \"Software\"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}],"content_type":"text/markdown"}